@@ -1,4 +1,5 @@
 import io
+import socket
 from contextlib import redirect_stderr
 
 import pydevd_pycharm
@@ -8,9 +9,10 @@ import waiting
 class PycharmRemoteDebugger:
     DEFAULT_CONNECTION_TIMEOUT = 30
 
-    def __init__(self, remote_machine: str, port: int) -> None:
+    def __init__(self, remote_machine: str, port: int, optional=False) -> None:
         self._remote_machine: str = remote_machine
         self._port: int = port
+        self._optional = optional
 
     def _debugger_login(self) -> bool:
         f = io.StringIO()
@@ -23,9 +25,14 @@ class PycharmRemoteDebugger:
                 return False
 
     def wait_for_debugger(self, timeout=DEFAULT_CONNECTION_TIMEOUT):
-        waiting.wait(
-            lambda: self._debugger_login(),
-            timeout_seconds=timeout,
-            sleep_seconds=1,
-            waiting_for="remote debugger to be ready"
-        )
+        try:
+
+            waiting.wait(
+                lambda: self._debugger_login(),
+                timeout_seconds=timeout,
+                sleep_seconds=1,
+                waiting_for="remote debugger to be ready"
+            )
+        except socket.timeout:
+            if not self._optional:
+                raise
